@@ -16,8 +16,6 @@
 
 #define QT_FEATURE_glib -1
 
-#define QT_FEATURE_glibc -1
-
 #define QT_FEATURE_icu -1
 
 #define QT_FEATURE_inotify -1
@@ -28,6 +26,10 @@
 
 #define QT_FEATURE_linkat -1
 
+#define QT_FEATURE_memmem -1
+
+#define QT_FEATURE_memrchr -1
+
 #define QT_FEATURE_mimetype_database 1
 
 #define QT_FEATURE_system_pcre2 1
@@ -50,8 +52,6 @@
 
 #define QT_FEATURE_slog2 -1
 
-#define QT_FEATURE_statx -1
-
 #define QT_FEATURE_syslog -1
 
 #define QT_FEATURE_sysv_sem -1
@@ -60,12 +60,16 @@
 
 #define QT_FEATURE_backtrace -1
 
+#define QT_FEATURE_cxx23_stacktrace -1
+
 #define QT_FEATURE_cpp_winrt -1
 
 #define QT_FEATURE_sha3_fast 1
 
 #define QT_FEATURE_hijricalendar 1
 
+#define QT_FEATURE_timezone_locale -1
+
 #define QT_FEATURE_datetimeparser 1
 
 #define QT_FEATURE_lttng -1
